==> react-image-annotate-2.0.19.tgz: package/PageSelector/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState } from 'react';
import classnames from "classnames";
import './page-selector.css'; // {
//               showMetadata && (
//                 <div className="page-thumbnail__metadata">
//                   <h5>Metadata</h5>
//                   {
//                     page?.metadata?.map(({ key, value }) => (
//                       <div key={key}>
//                         <label htmlFor={key}>{key}</label>
//                         <input id={key} type="text" value={value} onChange={(e) => onMetadataChange({ name: key, value: e.target.value, imageIndex: idx })} />
//                       </div>
//                     ))
//                   }
//                 </div>
//               )
//             }

function PageThumbnail(_ref) {
  var src = _ref.src,
      isActive = _ref.isActive,
      onClick = _ref.onClick,
      pageNumber = _ref.pageNumber;
  return React.createElement("div", {
    role: "button",
    tabIndex: 0,
    className: classnames('page-thumbnail', {
      'page-thumbnail-is-active': isActive
    }),
    onClick: onClick
  }, React.createElement("img", {
    src: src,
    alt: "",
    className: "page-thumbnail-image"
  }), React.createElement("div", {
    className: "page-number-wrapper"
  }, pageNumber !== undefined && React.createElement("span", {
    className: "page-number"
  }, pageNumber)), " */");
}

function PageSelector(_ref2) {
  var pages = _ref2.pages,
      onPageClick = _ref2.onPageClick,
      onRecalc = _ref2.onRecalc,
      onSave = _ref2.onSave,
      recalcActive = _ref2.recalcActive,
      saveActive = _ref2.saveActive,
      onMetadataChange = _ref2.onMetadataChange;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      showMetadata = _useState2[0],
      setShowMetadata = _useState2[1];

  return React.createElement("div", {
    className: classnames('page-selector', {
      'page-selector--opened': showMetadata
    })
  }, React.createElement("div", {
    className: "top-buttons"
  }, React.createElement("button", {
    onClick: onRecalc,
    disabled: !recalcActive,
    className: "info"
  }, "Recalc"), React.createElement("button", {
    onClick: onSave,
    disabled: !saveActive,
    className: "success"
  }, "Save"), React.createElement("div", {
    className: "show-metadata-wrapper"
  }, React.createElement("label", {
    className: "switch mr-2"
  }, React.createElement("input", {
    id: "show-metadata",
    type: "checkbox",
    value: showMetadata,
    onChange: function onChange() {
      return setShowMetadata(function (prev) {
        return !prev;
      });
    }
  }), React.createElement("span", {
    className: "slider round"
  })), React.createElement("label", null, "Metadata"))), React.createElement("div", {
    className: "pages"
  }, pages.map(function (page, idx) {
    return React.createElement(PageThumbnail, {
      key: "".concat(page.id),
      src: page.src,
      isActive: page.isActive,
      onClick: function onClick() {
        return onPageClick(idx);
      }
    });
  })));
}

PageSelector.defaultProps = {
  onPageClick: function onPageClick() {},
  onRecalc: function onRecalc() {},
  onSave: function onSave() {},
  recalcActive: false,
  saveActive: false,
  pageNumber: undefined
};
export default PageSelector;

==> react-image-annotate-2.0.21.tgz: package/PageSelector/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState } from 'react';
import classnames from "classnames";
import './page-selector.css';

function PageThumbnail(_ref) {
  var src = _ref.src,
      isActive = _ref.isActive,
      onClick = _ref.onClick,
      pageNumber = _ref.pageNumber,
      metadata = _ref.metadata,
      showMetadata = _ref.showMetadata;
  return React.createElement("div", {
    role: "button",
    tabIndex: 0,
    className: classnames('page-thumbnail', {
      'page-thumbnail-is-active': isActive
    }),
    onClick: onClick
  }, React.createElement("div", {
    className: "page-thumbnail-image-wrapper"
  }, React.createElement("img", {
    src: src,
    alt: "",
    className: "page-thumbnail-image"
  }), React.createElement("div", {
    className: "page-number-wrapper"
  }, pageNumber !== undefined && !showMetadata && React.createElement("span", {
    className: "page-number"
  }, pageNumber))), React.createElement("div", {
    className: "page-thumbnail-metadata-wrapper"
  }, React.createElement("label", {
    htmlFor: true
  }, "Page"), React.createElement("input", {
    type: "text",
    value: "2"
  }), React.createElement("label", {
    htmlFor: true
  }, "Topic"), React.createElement("input", {
    type: "text",
    value: "012345678901234567890123456789"
  }), React.createElement("label", {
    htmlFor: true
  }, "Mutation"), React.createElement("input", {
    type: "text",
    value: "2"
  }), React.createElement("label", {
    htmlFor: true
  }, "Page"), React.createElement("input", {
    type: "text",
    value: "2"
  }), React.createElement("label", {
    htmlFor: true
  }, "Topic"), React.createElement("input", {
    type: "text",
    value: "012345678901234567890123456789"
  }), React.createElement("label", {
    htmlFor: true
  }, "Mutation"), React.createElement("input", {
    type: "text",
    value: "2"
  })));
}

function PageSelector(_ref2) {
  var pages = _ref2.pages,
      onPageClick = _ref2.onPageClick,
      onRecalc = _ref2.onRecalc,
      onSave = _ref2.onSave,
      recalcActive = _ref2.recalcActive,
      saveActive = _ref2.saveActive,
      onMetadataChange = _ref2.onMetadataChange;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      showMetadata = _useState2[0],
      setShowMetadata = _useState2[1];

  return React.createElement("div", {
    className: classnames('page-selector', {
      'page-selector--opened': showMetadata
    })
  }, React.createElement("div", {
    className: "top-buttons"
  }, React.createElement("button", {
    onClick: onRecalc,
    disabled: !recalcActive,
    className: "info"
  }, "Recalc"), React.createElement("button", {
    onClick: onSave,
    disabled: !saveActive,
    className: "success"
  }, "Save"), React.createElement("div", {
    className: "show-metadata-wrapper"
  }, React.createElement("label", {
    className: "switch mr-2"
  }, React.createElement("input", {
    id: "show-metadata",
    type: "checkbox",
    value: showMetadata,
    onChange: function onChange() {
      return setShowMetadata(function (prev) {
        return !prev;
      });
    }
  }), React.createElement("span", {
    className: "slider round"
  })), React.createElement("label", null, "Metadata"))), React.createElement("div", {
    className: "pages"
  }, pages.map(function (page, idx) {
    return React.createElement(PageThumbnail, {
      key: "".concat(page.id),
      src: page.src,
      isActive: page.isActive,
      onClick: function onClick() {
        return onPageClick(idx);
      },
      metadata: page.metadata,
      showMetadata: showMetadata
    });
  })));
}

PageSelector.defaultProps = {
  onPageClick: function onPageClick() {},
  onRecalc: function onRecalc() {},
  onSave: function onSave() {},
  recalcActive: false,
  saveActive: false,
  pageNumber: undefined
};
export default PageSelector;
